# Code of Conduct

## Our Pledge

In the interest of fostering an open and welcoming environment, we as contributors and maintainers pledge to making participation in our project and our community a harassment-free experience for everyone, regardless of age, body size, disability, ethnicity, gender identity and expression, level of experience, nationality, personal appearance, race, religion, or sexual identity and orientation.

## Our Standards

Examples of behavior that contributes to a positive environment include:

* **Be Excellent to Each Other:** Treat everyone with respect, kindness, and empathy.
* **Focus on What is Best for the Community:** We are here to build a great tool together.
* **Gracefully Accept Constructive Criticism:** Feedback is how we improve.
* **Use Welcoming and Inclusive Language:** This is a global community.

Examples of unacceptable behavior include:

* Trolling, insulting/derogatory comments, and personal or political attacks.
* Public or private harassment.
* Publishing others' private information without explicit permission.
* Other conduct which could reasonably be considered inappropriate in a professional setting.

## Enforcement

Project maintainers have the right and responsibility to remove, edit, or reject comments, commits, code, wiki edits, issues, and other contributions that are not aligned to this Code of Conduct, or to ban temporarily or permanently any contributor for other behaviors that they deem inappropriate, threatening, offensive, or harmful.

## Attribution

This Code of Conduct is adapted from the [Contributor Covenant](https://www.contributor-covenant.org), version 1.4.